@@ -11,5 +11,6 @@ $p = pdl [ 1, 1 ]; # initial  parameter guesses
 $h = levmar($p,$x,$t, FUNC =>
                 '   function
                      x = p0 * exp( -t*t * p1);
-           ');
+           ',
+     NOCLEAN => 1);
 print levmar_report($h);
